@@ -1,5 +1,7 @@
 from typing import Optional
 from django.contrib.auth.backends import BaseBackend
+from django.contrib.auth.models import Group
+from django.db.utils import ProgrammingError
 from .models import OauthUser
 from sso_auth.services.get_user_info import GetUserInfo
 
@@ -19,6 +21,7 @@ class TokenAuth(BaseBackend):
 		
 		if info.get('user_id'):
 			user = OauthUser()
+			
 			user.id = info.get('user_id')
 			user.identifier = info.get('username')
 			
@@ -36,6 +39,26 @@ class TokenAuth(BaseBackend):
 			user.is_anonymous = False
 			user.email = info.get('email')
 			
+			groups = Group.objects.filter(name__in=info.get('groups'))
+			
+			try:
+				user.groups.clear()
+				user.user_permissions.clear()
+			except ProgrammingError:
+				pass
+			
+			try:
+				for group in groups:
+					permissions = group.permissions.all()
+	
+					for permission in permissions:
+						user.user_permissions.add(permission.id)
+					user.groups.add(group.id)
+			except ProgrammingError:
+				pass
+				
+			user.save()
+			
 			return user
 		
 		return None
